# -*- coding: utf-8 -*-

"""Top-level package for favico."""

from favico.favico import generate

__author__ = """romnn"""
__email__ = "contact@romnn.com"
__version__ = "0.1.5"

__all__ = ["generate"]
